@@ -1,14 +1,14 @@
 /*-------------------------------------------------------------------------
  *
- * guc.c: guc variable handling of pg_stat_monitor
+ * guc.c
+ *	  guc variable handling of pg_stat_monitor
  *
- * Portions Copyright © 2018-2020, Percona LLC and/or its affiliates
+ * Portions Copyright © 2018-2024, Percona LLC and/or its affiliates
  *
- * Portions Copyright (c) 1996-2020, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * Portions Copyright (c) 1994, The Regents of the University of California
  *
- *
  * IDENTIFICATION
  *	  contrib/pg_stat_monitor/guc.c
  *
@@ -33,6 +33,7 @@ bool		pgsm_enable_query_plan;
 bool		pgsm_enable_overflow;
 bool		pgsm_normalized_query;
 bool		pgsm_track_utility;
+bool		pgsm_track_application_names;
 bool		pgsm_enable_pgsm_query_id;
 int			pgsm_track;
 static int	pgsm_overflow_target;	/* Not used since 2.0 */
@@ -48,7 +49,7 @@ static bool check_overflow_targer(int *newval, void **extra, GucSource source);
 void
 init_guc(void)
 {
-    pgsm_track = PGSM_TRACK_TOP;
+	pgsm_track = PGSM_TRACK_TOP;
 
 	DefineCustomIntVariable("pg_stat_monitor.pgsm_max", /* name */
 							"Sets the maximum size of shared memory in (MB) used for statement's metadata tracked by pg_stat_monitor.", /* short_desc */
@@ -190,6 +191,18 @@ init_guc(void)
 							 NULL	/* show_hook */
 		);
 
+	DefineCustomBoolVariable("pg_stat_monitor.pgsm_track_application_names",	/* name */
+							 "Enable/Disable application names tracking.",	/* short_desc */
+							 NULL,	/* long_desc */
+							 &pgsm_track_application_names, /* value address */
+							 true,	/* boot value */
+							 PGC_USERSET,	/* context */
+							 0, /* flags */
+							 NULL,	/* check_hook */
+							 NULL,	/* assign_hook */
+							 NULL	/* show_hook */
+		);
+
 	DefineCustomBoolVariable("pg_stat_monitor.pgsm_enable_pgsm_query_id",	/* name */
 							 "Enable/disable PGSM specific query id calculation which is very useful in comparing same query across databases and clusters..",	/* short_desc */
 							 NULL,	/* long_desc */
