@@ -1,11 +1,11 @@
 /*-------------------------------------------------------------------------
  *
  * pg_stat_monitor.h
- *		Track statement execution times across a whole database cluster.
+ *	  Track statement execution times across a whole database cluster.
  *
- * Portions Copyright © 2018-2020, Percona LLC and/or its affiliates
+ * Portions Copyright © 2018-2024, Percona LLC and/or its affiliates
  *
- * Portions Copyright (c) 1996-2020, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * Portions Copyright (c) 1994, The Regents of the University of California
  *
@@ -93,8 +93,8 @@
 /* the assumption of query max nested level */
 #define DEFAULT_MAX_NESTED_LEVEL	10
 
-#define MAX_QUERY_BUF						(pgsm_query_shared_buffer * 1024 * 1024)
-#define MAX_BUCKETS_MEM 					(pgsm_max * 1024 * 1024)
+#define MAX_QUERY_BUF						((int64)pgsm_query_shared_buffer * 1024 * 1024)
+#define MAX_BUCKETS_MEM 					((int64)pgsm_max * 1024 * 1024)
 #define BUCKETS_MEM_OVERFLOW() 				((hash_get_num_entries(pgsm_hash) * sizeof(pgsmEntry)) >= MAX_BUCKETS_MEM)
 #define MAX_BUCKET_ENTRIES 					(MAX_BUCKETS_MEM / sizeof(pgsmEntry))
 #define QUERY_BUFFER_OVERFLOW(x,y)  		((x + y + sizeof(uint64) + sizeof(uint64)) > MAX_QUERY_BUF)
@@ -195,7 +195,7 @@ typedef enum pgsmStoreKind
 	PGSM_ERROR,
 
 	PGSM_NUMKIND				/* Must be last value of this enum */
-}			pgsmStoreKind;
+} pgsmStoreKind;
 
 /* the assumption of query max nested level */
 #define DEFAULT_MAX_NESTED_LEVEL	10
@@ -208,7 +208,7 @@ typedef enum AGG_KEY
 	AGG_KEY_DATABASE = 0,
 	AGG_KEY_USER,
 	AGG_KEY_HOST
-}			AGG_KEY;
+} AGG_KEY;
 
 #define MAX_QUERY_LEN 1024
 
@@ -220,7 +220,7 @@ typedef struct CallTime
 	double		max_time;		/* maximum execution time in msec */
 	double		mean_time;		/* mean execution time in msec */
 	double		sum_var_time;	/* sum of variances in execution time in msec */
-}			CallTime;
+} CallTime;
 
 
 typedef struct PlanInfo
@@ -228,7 +228,7 @@ typedef struct PlanInfo
 	uint64		planid;			/* plan identifier */
 	char		plan_text[PLAN_TEXT_LEN];	/* plan text */
 	size_t		plan_len;		/* strlen(plan_text) */
-}			PlanInfo;
+} PlanInfo;
 
 typedef struct pgsmHashKey
 {
@@ -240,11 +240,11 @@ typedef struct pgsmHashKey
 	Oid			dbid;			/* database OID */
 	uint32		ip;				/* client ip address */
 	bool		toplevel;		/* query executed at top level */
-}			pgsmHashKey;
+	uint64		parentid;		/* parent queryid of current query */
+} pgsmHashKey;
 
 typedef struct QueryInfo
 {
-	uint64		parentid;		/* parent queryid of current query */
 	dsa_pointer parent_query;
 	int64		type;			/* type of query, options are query, info,
 								 * warning, error, fatal */
@@ -262,14 +262,14 @@ typedef struct ErrorInfo
 	int64		elevel;			/* error elevel */
 	char		sqlcode[SQLCODE_LEN];	/* error sqlcode  */
 	char		message[ERROR_MESSAGE_LEN]; /* error message text */
-}			ErrorInfo;
+} ErrorInfo;
 
 typedef struct Calls
 {
 	int64		calls;			/* # of times executed */
 	int64		rows;			/* total # of retrieved or affected rows */
 	double		usage;			/* usage factor */
-}			Calls;
+} Calls;
 
 
 typedef struct Blocks
@@ -284,9 +284,14 @@ typedef struct Blocks
 	int64		local_blks_written; /* # of local disk blocks written */
 	int64		temp_blks_read; /* # of temp blocks read */
 	int64		temp_blks_written;	/* # of temp blocks written */
-	double		blk_read_time;	/* time spent reading, in msec */
-	double		blk_write_time; /* time spent writing, in msec */
-
+	double		shared_blk_read_time;	/* time spent reading shared blocks,
+										 * in msec */
+	double		shared_blk_write_time;	/* time spent writing shared blocks,
+										 * in msec */
+	double		local_blk_read_time;	/* time spent reading local blocks, in
+										 * msec */
+	double		local_blk_write_time;	/* time spent writing local blocks, in
+										 * msec */
 	double		temp_blk_read_time; /* time spent reading temp blocks, in msec */
 	double		temp_blk_write_time;	/* time spent writing temp blocks, in
 										 * msec */
@@ -295,11 +300,15 @@ typedef struct Blocks
 	 * Variables for local entry. The values to be passed to pgsm_update_entry
 	 * from pgsm_store.
 	 */
-	instr_time	instr_blk_read_time;	/* time spent reading blocks */
-	instr_time	instr_blk_write_time;	/* time spent writing blocks */
+	instr_time	instr_shared_blk_read_time; /* time spent reading shared
+											 * blocks */
+	instr_time	instr_shared_blk_write_time;	/* time spent writing shared
+												 * blocks */
+	instr_time	instr_local_blk_read_time;	/* time spent reading local blocks */
+	instr_time	instr_local_blk_write_time; /* time spent writing local blocks */
 	instr_time	instr_temp_blk_read_time;	/* time spent reading temp blocks */
 	instr_time	instr_temp_blk_write_time;	/* time spent writing temp blocks */
-}			Blocks;
+} Blocks;
 
 typedef struct JitInfo
 {
@@ -307,6 +316,9 @@ typedef struct JitInfo
 	double		jit_generation_time;	/* total time to generate jit code */
 	int64		jit_inlining_count; /* number of times inlining time has been
 									 * > 0 */
+	double		jit_deform_time;	/* total time to deform tuples in jit code */
+	int64		jit_deform_count;	/* number of times deform time has been >
+									 * 0 */
 	double		jit_inlining_time;	/* total time to inline jit code */
 	int64		jit_optimization_count; /* number of times optimization time
 										 * has been > 0 */
@@ -321,22 +333,23 @@ typedef struct JitInfo
 	 */
 	instr_time	instr_generation_counter;	/* generation counter */
 	instr_time	instr_inlining_counter; /* inlining counter */
+	instr_time	instr_deform_counter;	/* deform counter */
 	instr_time	instr_optimization_counter; /* optimization counter */
 	instr_time	instr_emission_counter; /* emission counter */
-}			JitInfo;
+} JitInfo;
 
 typedef struct SysInfo
 {
 	double		utime;			/* user cpu time */
 	double		stime;			/* system cpu time */
-}			SysInfo;
+} SysInfo;
 
 typedef struct Wal_Usage
 {
 	int64		wal_records;	/* # of WAL records generated */
 	int64		wal_fpi;		/* # of WAL full page images generated */
 	uint64		wal_bytes;		/* total amount of WAL bytes generated */
-}			Wal_Usage;
+} Wal_Usage;
 
 typedef struct Counters
 {
@@ -370,13 +383,15 @@ typedef struct pgsmEntry
 	char		username[NAMEDATALEN];	/* user name */
 	Counters	counters;		/* the statistics for this query */
 	int			encoding;		/* query text encoding */
+	TimestampTz stats_since;	/* timestamp of entry allocation */
+	TimestampTz minmax_stats_since; /* timestamp of last min/max values reset */
 	slock_t		mutex;			/* protects the counters only */
 	union
 	{
 		dsa_pointer query_pos;	/* query location within query buffer */
 		char	   *query_pointer;
 	}			query_text;
-}			pgsmEntry;
+} pgsmEntry;
 
 /*
  * Global shared state
@@ -399,8 +414,8 @@ typedef struct pgsmSharedState
 	 */
 
 	bool		pgsm_oom;
-	TimestampTz bucket_start_time[]; /* start time of the bucket */
-}			pgsmSharedState;
+	TimestampTz bucket_start_time[];	/* start time of the bucket */
+} pgsmSharedState;
 
 typedef struct pgsmLocalState
 {
@@ -408,9 +423,9 @@ typedef struct pgsmLocalState
 	dsa_area   *dsa;			/* local dsa area for backend attached to the
 								 * dsa area created by postmaster at startup. */
 	PGSM_HASH_TABLE *shared_hash;
-    MemoryContext pgsm_mem_cxt;
+	MemoryContext pgsm_mem_cxt;
 
-}			pgsmLocalState;
+} pgsmLocalState;
 
 #if PG_VERSION_NUM < 140000
 /*
@@ -465,7 +480,7 @@ pgsmSharedState *pgsm_get_ss(void);
 void		hash_query_entries();
 void		hash_query_entry_dealloc(int new_bucket_id, int old_bucket_id, unsigned char *query_buffer[]);
 void		hash_entry_dealloc(int new_bucket_id, int old_bucket_id, unsigned char *query_buffer);
-pgsmEntry  *hash_entry_alloc(pgsmSharedState * pgsm, pgsmHashKey * key, int encoding);
+pgsmEntry  *hash_entry_alloc(pgsmSharedState *pgsm, pgsmHashKey *key, int encoding);
 Size		pgsm_ShmemSize(void);
 void		pgsm_startup(void);
 
@@ -483,7 +498,7 @@ typedef enum
 	PSGM_TRACK_NONE = 0,		/* track no statements */
 	PGSM_TRACK_TOP,				/* only top level statements */
 	PGSM_TRACK_ALL				/* all statements, including nested ones */
-}			PGSMTrackLevel;
+} PGSMTrackLevel;
 static const struct config_enum_entry track_options[] =
 {
 	{"none", PSGM_TRACK_NONE, false},
@@ -497,7 +512,7 @@ typedef enum
 	HISTOGRAM_START,
 	HISTOGRAM_END,
 	HISTOGRAM_COUNT
-}			HistogramTimingType;
+} HistogramTimingType;
 
 extern int	pgsm_max;
 extern int	pgsm_query_max_len;
@@ -513,6 +528,7 @@ extern bool pgsm_enable_query_plan;
 extern bool pgsm_enable_overflow;
 extern bool pgsm_normalized_query;
 extern bool pgsm_track_utility;
+extern bool pgsm_track_application_names;
 extern bool pgsm_enable_pgsm_query_id;
 extern int	pgsm_track;
 
@@ -522,8 +538,8 @@ extern int	pgsm_track;
 #define HOOK_STATS_SIZE 0
 #endif
 
-void	   *pgsm_hash_find_or_insert(PGSM_HASH_TABLE * shared_hash, pgsmHashKey * key, bool *found);
-void	   *pgsm_hash_find(PGSM_HASH_TABLE * shared_hash, pgsmHashKey * key, bool *found);
+void	   *pgsm_hash_find_or_insert(PGSM_HASH_TABLE * shared_hash, pgsmHashKey *key, bool *found);
+void	   *pgsm_hash_find(PGSM_HASH_TABLE * shared_hash, pgsmHashKey *key, bool *found);
 void		pgsm_hash_seq_init(PGSM_HASH_SEQ_STATUS * hstat, PGSM_HASH_TABLE * shared_hash, bool lock);
 void	   *pgsm_hash_seq_next(PGSM_HASH_SEQ_STATUS * hstat);
 void		pgsm_hash_seq_term(PGSM_HASH_SEQ_STATUS * hstat);
